check_truncation_length: Check and warn if truncation distribution is longer than...

View source: R/checks.R

check_truncation_lengthR Documentation

Check and warn if truncation distribution is longer than observed time

Description

Checks if the truncation distribution PMF is longer than the observed time period (excluding seeding time and forecast horizon). The truncation is applied to the observed time period in the Stan model, so having a truncation distribution longer than this period means the tail of the distribution will be used.

Usage

check_truncation_length(stan_args, time_points)

Arguments

stan_args

List of stan arguments including the data element with delay information from create_stan_delays()

time_points

Integer length of the observed time period (t - seeding_time - horizon)

Value

Called for its side effects


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.