| create_infection_summary | R Documentation |
This function creates summary output from infection estimation objects
(either estimate_infections or forecast_infections). It is used
internally by summary.estimate_infections() and
summary.forecast_infections() to provide a consistent summary interface.
create_infection_summary(
object,
type = c("snapshot", "parameters"),
target_date = NULL,
params = NULL,
CrIs = c(0.2, 0.5, 0.9),
...
)
object |
An infection estimation object (either from
|
type |
A character vector of data types to return. Defaults to
"snapshot" but also supports "parameters". "snapshot" returns
a summary at a given date (by default the latest date informed by data).
"parameters" returns summarised parameter estimates that can be further
filtered using |
target_date |
Date, defaults to maximum found in the data if not specified. |
params |
A character vector of parameters to filter for. |
CrIs |
Numeric vector of credible intervals to calculate. Defaults to c(0.2, 0.5, 0.9). |
... |
Additional arguments passed to |
A <data.frame> of summary output, either a snapshot summary
(via report_summary()) or parameter summaries (via
calc_summary_measures()).
summary.estimate_infections() summary.forecast_infections()
report_summary() calc_summary_measures()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.