| discretise | R Documentation |
Discretise a <dist_spec>
## S3 method for class 'dist_spec'
discretise(x, strict = TRUE, remove_trailing_zeros = TRUE, ...)
discretize(x, ...)
x |
A |
strict |
Logical; If |
remove_trailing_zeros |
Logical; If |
... |
ignored |
A <dist_spec> where all distributions with constant parameters are
nonparametric.
The probability mass function is computed using the {primarycensored}
package, which provides double censored PMF calculations. This correctly
represents the probability mass function of a double censored distribution
arising from the difference of two censored events.
The probability mass function of the discretised probability distribution is a vector where the first entry corresponds to the integral over the (0,1] interval of the corresponding continuous distribution (probability of integer 0), the second entry corresponds to the (0,2] interval (probability mass of integer 1), the third entry corresponds to the (1, 3] interval (probability mass of integer 2), etc.
Charniga, K., et al. "Best practices for estimating and reporting epidemiological delay distributions of infectious diseases using public health surveillance and healthcare data", arXiv e-prints, 2024. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2405.08841")} Park, S. W., et al., "Estimating epidemiological delay distributions for infectious diseases", medRxiv, 2024. \Sexpr[results=rd]{tools:::Rd_expr_doi("https://doi.org/10.1101/2024.01.12.24301247")} Abbott S., et al., "primarycensored: Primary Event Censored Distributions", 2025. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5281/zenodo.13632839")}
# A fixed gamma distribution with mean 5 and sd 1.
dist1 <- Gamma(mean = 5, sd = 1, max = 20)
# An uncertain lognormal distribution with meanlog and sdlog normally
# distributed as Normal(3, 0.5) and Normal(2, 0.5) respectively
dist2 <- LogNormal(
meanlog = Normal(3, 0.5),
sdlog = Normal(2, 0.5),
max = 20
)
# The maxf the sum of two distributions
discretise(dist1 + dist2, strict = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.