estimate_delay: Estimate a Delay Distribution

View source: R/estimate_delay.R

estimate_delayR Documentation

Estimate a Delay Distribution

Description

[Deprecated] Estimate a log normal delay distribution from a vector of integer delays.

This function is deprecated. Please use estimate_dist() instead, which provides better handling of censoring and truncation.

Usage

estimate_delay(delays, ...)

Arguments

delays

Integer vector of delays

...

Arguments to pass to internal methods.

Value

A ⁠<dist_spec>⁠ summarising the bootstrapped distribution

See Also

estimate_dist() for the recommended replacement

Examples


delays <- rlnorm(500, log(5), 1)
# Old way (deprecated):
# estimate_delay(delays, samples = 1000, bootstraps = 10)

# New way: see ?estimate_dist and
# vignette("estimate_dist_workflow") for date-based usage


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.