example_truncated: Example Case Data Set with Truncation

example_truncatedR Documentation

Example Case Data Set with Truncation

Description

An example dataset of observed cases with truncation applied. This data is generated internally for use in the example of estimate_truncation(). For details on how the data is generated, see https://github.com/epiforecasts/EpiNow2/blob/main/data-raw/truncated.R #nolint

Usage

example_truncated

Format

A list of data.tables containing cases reported on each date until a point of truncation. Each element of the list is a data.table with the following columns:

date

Date of case report.

confirm

Number of confirmed cases.


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.