extract_delay_params: Extract delay distributions from a fitted model

extract_delay_paramsR Documentation

Extract delay distributions from a fitted model

Description

Internal helper to extract delay distributions from the ⁠delay_id_*⁠ variables in stan data.

Usage

extract_delay_params(x, stan_data)

Arguments

x

A fitted model object with ⁠$fit⁠ and ⁠$args⁠ components.

stan_data

The stan data list from x$args.

Value

A named list of dist_spec objects representing the posterior distributions of delay parameters.


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.