| extract_delays | R Documentation |
Extracts samples from all delay parameters using the delay ID lookup system. Similar to extract_parameters(), this extracts all delay distribution parameters and uses the *_id variables (e.g., delay_id, trunc_id) to assign meaningful names.
extract_delays(samples, args)
samples |
Extracted stan model (using |
args |
Stan data list with delay_id_* and related lookup variables. |
A <data.table> with columns: variable, sample, value,
or NULL if delay parameters don't exist in the samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.