Fits a stan model using variational inference.
fit_model_with_vb(args, future = FALSE, id = "stan")List of stan arguments
Logical, defaults to FALSE. Should future be used to run stan chains in parallel.
A character string used to assign logging information on error. Used by regional_epinow
to assign errors to regions. Alter the default to run with error catching.
A stan model object