lower_bounds: Get the lower bounds of the parameters of a distribution

View source: R/dist_spec.R

lower_boundsR Documentation

Get the lower bounds of the parameters of a distribution

Description

This is used to avoid sampling parameter values that have no support.

Usage

lower_bounds(distribution)

Arguments

distribution

Character; the distribution to use.

Value

A numeric vector, the lower bounds.

Examples

## Not run: 
lower_bounds("lognormal")

## End(Not run)

EpiNow2 documentation built on June 17, 2026, 1:07 a.m.