plot_CrIs: Plot EpiNow2 Credible Intervals

View source: R/plot.R

plot_CrIsR Documentation

Plot EpiNow2 Credible Intervals

Description

Adds credible intervals to a plot, either as ribbons or error bars.

Usage

plot_CrIs(plot, CrIs, alpha, linewidth, style = c("ribbon", "linerange"))

Arguments

plot

A {ggplot2} plot

CrIs

Numeric list of credible intervals present in the data. As produced by extract_CrIs().

alpha

Numeric, overall alpha of the target line range.

linewidth

Numeric, line width of the default line range.

style

Character string indicating the plot style. Options are "ribbon" (default) for shaded ribbon plots or "linerange" for error bars.

Value

A {ggplot2} plot.


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.