| posterior_to_normal | R Documentation |
Helper function to create a Normal distribution from a row of posterior summary statistics, with consistent rounding.
posterior_to_normal(posterior, idx)
posterior |
Data frame with |
idx |
Integer index into the posterior data frame |
A Normal distribution object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.