View source: R/estimate_truncation.R
| prepare_truncation_obs | R Documentation |
Internal function to process a list of observation snapshots into the matrix format required by the truncation Stan model.
prepare_truncation_obs(data, trunc_max)
data |
A list of |
trunc_max |
Integer, the maximum truncation delay to consider. |
A list containing:
obs: Matrix of observations (time x datasets)
obs_dist: Vector of NA counts per dataset (used to determine truncation)
t: Number of time points
obs_sets: Number of observation datasets
dirty_obs: The processed data.tables (ordered by nrow)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.