print.epinowfit: Print information about an object that has resulted from a...

print.epinowfitR Documentation

Print information about an object that has resulted from a model fit.

Description

Print information about an object that has resulted from a model fit.

Usage

## S3 method for class 'epinowfit'
print(x, ...)

Arguments

x

The object containing fit results.

...

Ignored

Value

Invisible


EpiNow2 documentation built on June 17, 2026, 1:07 a.m.