| select_plots | R Documentation |
report_plots()Internal helper function to select plots from those created by
report_plots()
select_plots(
plots,
type = c("summary", "infections", "reports", "R", "growth_rate", "all")
)
plots |
A list of plots as produced by |
type |
A character vector indicating the name of the plot to return. Defaults to "summary" with supported options being "infections", "reports", "R", "growth_rate", "summary", "all". If "all" is supplied all plots are generated. |
Selected plots by type
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.