| summary.estimate_infections | R Documentation |
summary method for class "estimate_infections".
## S3 method for class 'estimate_infections'
summary(
object,
type = c("snapshot", "parameters"),
target_date = NULL,
params = NULL,
CrIs = c(0.2, 0.5, 0.9),
...
)
object |
A list of output as produced by "estimate_infections". |
type |
A character vector of data types to return. Defaults to
"snapshot" but also supports "parameters". "snapshot" returns a summary at
a given date (by default the latest date informed by data). "parameters"
returns summarised parameter estimates that can be further filtered using
Note: |
target_date |
Date, defaults to maximum found in the data if not specified. |
params |
A character vector of parameters to filter for. |
CrIs |
Numeric vector of credible intervals to calculate. |
... |
Pass additional arguments to |
Returns a <data.frame> of summary output
summary.epinow() estimate_infections() report_summary()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.