| summary.estimate_secondary | R Documentation |
Returns a summary of the fitted secondary model including posterior parameter estimates with credible intervals.
## S3 method for class 'estimate_secondary'
summary(
object,
type = c("compact", "parameters"),
params = NULL,
CrIs = c(0.2, 0.5, 0.9),
...
)
object |
A fitted model object from |
type |
Character string indicating the type of summary to return. Options are "compact" (default) which returns delay distribution parameters and scaling factors, or "parameters" for all parameters or a filtered set. |
params |
Character vector of parameter names to include. Only used
when |
CrIs |
Numeric vector of credible intervals to calculate. |
... |
Additional arguments (currently unused) |
A <data.table> with summary statistics (mean, sd, median,
credible intervals) for model parameters. When type = "compact",
returns only key parameters (delay distribution parameters and scaling
factors). When type = "parameters", returns all or filtered parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.