| check_simulation_input | R Documentation |
Checks that a data frame intended for simulation has the required date
column and a named numeric value column, that the date column is in date
format, and that the value column contains non-negative numeric values with
no missing entries.
check_simulation_input(data, value_col)
data |
A data frame with at least a |
value_col |
Character; name of the numeric value column to check. |
Called for its side effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.