| check_truncation_length | R Documentation |
Checks if the truncation distribution PMF is longer than the observed time period (excluding seeding time and forecast horizon). The truncation is applied to the observed time period in the Stan model, so having a truncation distribution longer than this period means the tail of the distribution will be used.
check_truncation_length(stan_args, time_points)
stan_args |
List of stan arguments including the data element with
delay information from |
time_points |
Integer length of the observed time period (t - seeding_time - horizon) |
Called for its side effects
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.