| plot_CrIs | R Documentation |
Adds credible intervals to a plot, either as ribbons or error bars.
plot_CrIs(plot, CrIs, alpha, linewidth, style = c("ribbon", "linerange"))
plot |
A |
CrIs |
Numeric list of credible intervals present in the data. As
produced by |
alpha |
Numeric, overall alpha of the target line range. |
linewidth |
Numeric, line width of the default line range. |
style |
Character string indicating the plot style. Options are "ribbon" (default) for shaded ribbon plots or "linerange" for error bars. |
A {ggplot2} plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.