| stable_convolve | R Documentation |
Unlike stats::convolve(), this function does not use the FFT algorithm,
which can generate negative numbers when below machine precision.
stable_convolve(a, b)
a |
Numeric vector, the first sequence. |
b |
Numeric vector, the second sequence. |
A numeric vector representing the convolution of a and b.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.